@@ -90,14 +90,23 @@ class ProgressLogger:
     def log_metric(self, name: str, time_diff_in_minutes: float) -> None:
         self.logger.info(f"{name}: {time_diff_in_minutes} min")
         if self.mlflow_config is not None:
-            mlflow.log_metric(
-                key=self.__mlflow_clean_string(name), value=time_diff_in_minutes
-            )
+            try:
+                mlflow.log_metric(
+                    key=self.__mlflow_clean_string(name), value=time_diff_in_minutes
+                )
+            except Exception as e:
+                self.log_event("mlflow log metric error", str({e}))
 
     def log_param(self, key: str, value: str) -> None:
         self.logger.info(f"{key}: {value}")
         if self.mlflow_config is not None:
-            mlflow.log_param(key=self.__mlflow_clean_string(key), value=value)
+            try:
+                mlflow.log_param(
+                    key=self.__mlflow_clean_string(key),
+                    value=self.__mlflow_clean_param_value(value),
+                )
+            except Exception as e:
+                self.log_event("mlflow log param error", str({e}))
 
     def log_params(self, params: Dict[str, Any]) -> None:
         if self.mlflow_config is not None:
@@ -119,6 +128,18 @@ class ProgressLogger:
         value = value.replace("//", "/")
         return re.sub(r"[^\w\-\.\s\/]", "-", value)
 
+    def __mlflow_clean_param_value(self, param_value: str) -> str:
+        """
+        replace sensitive values in the string with asterisks
+        """
+        sensitive_value_replacement: str = "*******"
+        db_password_regex = r"(?<=:)\w+(?=@)"
+        cleaned_value = re.sub(
+            db_password_regex, sensitive_value_replacement, param_value
+        )
+
+        return cleaned_value
+
     # noinspection PyUnusedLocal
     def log_artifact(
         self, key: str, contents: str, folder_path: Optional[str] = None
@@ -135,7 +156,7 @@ class ProgressLogger:
                     mlflow.log_artifact(local_path=str(file_path))
 
         except Exception as e:
-            self.logger.warning(f"Error in log_artifact writing to mlflow: {str(e)}")
+            self.log_event("Error in log_artifact writing to mlflow", str(e))
 
     def write_to_log(self, name: str, message: str = "") -> bool:
         self.logger.info(name + ": " + str(message))
